# CRAFT

## Original code

[https://github.com/askerlee/craft](https://github.com/askerlee/craft)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@InProceedings{craft,
author="Sui, Xiuchao and Li, Shaohua and Geng, Xue and Wu, Yan and Xu, Xinxing and Liu, Yong and Goh, Rick Siow Mong and Zhu, Hongyuan",
title="CRAFT: Cross-Attentional Flow Transformers for Robust Optical Flow",
booktitle="CVPR",
year="2022"
}
```